/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.model;

import java.util.Date;

/**
 * Wraps a change committed to an SCM repository.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public class ScmRepositoryChange {
    /** Revision this change was made on. */
    private long revision;
    /** Date of this change. */
    private Date date;
    /** Author of this change. */
    private String author;
    /** Change log message. */
    private String message;

    /** Number of files added during this change. */
    private int addedFiles;
    /** Number of files deleted during this change. */
    private int deletedFiles;
    /** Number of files modified during this change. */
    private int modifiedFiles;
    /** Number of files replaced during this change. */
    private int replacedFiles;

    public ScmRepositoryChange(long revision, Date date, String author, String message, int addedFiles, int deletedFiles, int modifiedFiles, int replacedFiles) {
        this.revision = revision;
        this.date = date;
        this.author = author;
        this.message = message;

        this.addedFiles = addedFiles;
        this.deletedFiles = deletedFiles;
        this.modifiedFiles = modifiedFiles;
        this.replacedFiles = replacedFiles;
    }

    public long getRevision() {
        return revision;
    }

    public Date getDate() {
        return date;
    }

    public String getAuthor() {
        return author;
    }

    public String getMessage() {
        return message;
    }

    public int getAddedFiles() {
        return addedFiles;
    }

    public int getDeletedFiles() {
        return deletedFiles;
    }

    public int getModifiedFiles() {
        return modifiedFiles;
    }

    public int getReplacedFiles() {
        return replacedFiles;
    }

    /** Returns its age in milliseconds. */
    public long getAge() {
        return new Date().getTime() - date.getTime();
    }

    /** Returns its age in days. */
    public long getAgeInDays() {
        return getAge()/ModelUtils.MILLIS_PER_DAY;
    }
}
