/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.portlet.svn;

import hu.midori.kosmos.model.ModelUtils;
import hu.midori.kosmos.model.SvnRepository;
import hu.midori.kosmos.portlet.AbstractKosmosPortlet;
import hu.midori.kosmos.portlet.util.PortletUtils;
import hu.midori.kosmos.protocol.SvnService;

import java.net.MalformedURLException;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import javax.portlet.PortletConfig;
import javax.portlet.PortletException;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.caucho.hessian.client.HessianProxyFactory;

/**
 * Monitors <i>Subversion</i> repositories.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public class SvnMonitoringPortlet extends AbstractKosmosPortlet {
    private final static Log log = LogFactory.getLog(SvnMonitoringPortlet.class);
    
    private List<String> monitoredUrls = null;

    @Override
    public void init(PortletConfig config) throws PortletException {
        log.info("Initializing...");
        super.init(config);
        
        monitoredUrls = PortletUtils.breakCommaSeparatedString(config.getInitParameter("monitored.urls"));
        if(monitoredUrls == null)
            throw new IllegalStateException("'monitored.urls' was not specified in the init-params");
    }
    
    @Override
    public void destroy() {
        log.info("Destroying...");
    }
    
    @Override
    public void doView(RenderRequest request, RenderResponse response) {
        log.info("Viewing...");   

        // connect to web-service
        SvnService service = null;                
        HessianProxyFactory factory = new HessianProxyFactory();
        try {
            service = (SvnService)factory.create(SvnService.class, serviceUrl);
        } catch (MalformedURLException ex) {
            log.error("Unable to connect to the service", ex);
        }

        // get repository list if the service was successfully set-up
        Date timestamp = null;
        List<SvnRepository> repositories = null;
        if(service != null) {
            for(String monitoredUrl : monitoredUrls) {
                if(repositories == null)
                    repositories = service.getRepositories(monitoredUrl);
                else
                    repositories.addAll(service.getRepositories(monitoredUrl));
            }
            log.debug("SVN repositories downloaded: " + repositories.size());

            timestamp = service.getTimestamp();
            log.debug("SVN timestamp: " + timestamp);
        }

        // render response
        String id = request.getParameter("id");  
        getPortletContext().setAttribute("timestamp", timestamp);
        if(id != null) {
            // show details
            String action = request.getParameter("action");
            String page = action.equals("viewRepositoryDetails") ? "/pages/svn_monitoring_repository_details.jsp" : (action.equals("viewCommitterDetails") ? "/pages/svn_monitoring_committer_details.jsp" : (action.equals("viewRevisionDetails") ? "/pages/svn_monitoring_revision_details.jsp" : "/pages/svn_monitoring_activity_details.jsp"));
                
            SvnRepository repository = (SvnRepository)ModelUtils.findInCollection(repositories, id);
            if(repository != null) {
	            getPortletContext().setAttribute("repository", repository);        
	            getPortletContext().removeAttribute("repositories");
	        
	            renderJsp(request, response, page, String.format("%s [%s / %s]", getResourceBundle(Locale.getDefault()).getString("portlet.title"), monitoredResource, repository.getLocation()));
	            return;
            } else {
            	log.error(String.format("Repository \"%s\" not found", id));
            }
        }
        
        // show the full list
        getPortletContext().removeAttribute("repository");
        getPortletContext().setAttribute("repositories", repositories);
    
        renderJsp(request, response, "/pages/svn_monitoring.jsp", String.format("%s [%s - %d]", getResourceBundle(Locale.getDefault()).getString("portlet.title"), monitoredResource, repositories.size()));
    }

    @Override
    public void doHelp(RenderRequest request, RenderResponse response) {
        log.info("Helping...");   

        // render response
        renderJsp(request, response, "/pages/svn_monitoring_help.jsp", String.format("%s [%s]", getResourceBundle(Locale.getDefault()).getString("portlet.title"), monitoredResource));
    }     
}
